@@ -481,6 +481,45 @@ impl Compiler {
                         .emit_normal_op(ByteCode::EnterPathTracking, next);
                     Ok(next)
                 }),
+                "getpath" => {
+                    FunctionLike::ManuallyImplemented("getpath", |compiler, args, next| {
+                        assert_eq!(1, args.len());
+                        let next = compiler.emitter.emit_normal_op(ByteCode::Access, next);
+                        let next = compiler.compile_query(&args[0], next)?;
+                        let next = compiler.emitter.emit_normal_op(ByteCode::Dup, next);
+                        Ok(next)
+                    })
+                }
+                "group_by" => {
+                    FunctionLike::ManuallyImplemented("group_by", |compiler, args, next| {
+                        assert_eq!(1, args.len());
+                        let grouping = &args[0];
+                        // [.[] | [ [grouping], . ]] | group_by_impl
+                        let arg = Term::Array(Some(Box::new(Query::Pipe {
+                            lhs: Box::new(
+                                Term::Suffix(Term::Identity.into(), Suffix::Iterate).into(),
+                            ),
+                            rhs: Box::new(
+                                Term::Array(Some(Box::new(Query::Concat {
+                                    lhs: Box::new(
+                                        Term::Array(Some(Box::new(grouping.clone()))).into(),
+                                    ),
+                                    rhs: Box::new(Term::Identity.into()),
+                                })))
+                                .into(),
+                            ),
+                        })));
+                        let next = compiler.emitter.emit_normal_op(
+                            ByteCode::Intrinsic0(NamedFn0 {
+                                name: "group_by",
+                                func: intrinsic::group_by,
+                            }),
+                            next,
+                        );
+                        let next = compiler.compile_term(&arg, next)?;
+                        Ok(next)
+                    })
+                }
                 _ => return None,
             },
             _ => return None,
@@ -748,13 +787,7 @@ impl Compiler {
         let next = self
             .emitter
             .emit_normal_op(ByteCode::JumpUnless(negative_address), positive_address);
-        let next = self
-            .emitter
-            .emit_normal_op(ByteCode::ExitNonPathTracking, next);
-        let next = cond.compile(self, next)?;
-        let next = self
-            .emitter
-            .emit_normal_op(ByteCode::EnterNonPathTracking, next);
+        let next = self.compile_without_path_tracking(cond, next)?;
         let next = self.emitter.emit_normal_op(ByteCode::Dup, next);
         Ok(next)
     }
@@ -767,8 +800,8 @@ impl Compiler {
         next: Address,
     ) -> Result<Address> {
         let indexing = self.emitter.emit_normal_op(ByteCode::Index, next);
-        let index = index.compile(self, indexing)?;
-        let swap = self.emitter.emit_normal_op(ByteCode::Swap, index);
+        let indexing = self.compile_without_path_tracking(index, indexing)?;
+        let swap = self.emitter.emit_normal_op(ByteCode::Swap, indexing);
         let body = body.compile(self, swap)?;
         Ok(self.emitter.emit_normal_op(ByteCode::Dup, body))
     }
@@ -789,6 +822,9 @@ impl Compiler {
             },
             next,
         );
+        let next = self
+            .emitter
+            .emit_normal_op(ByteCode::ExitNonPathTracking, next);
         let mut need_val = false;
         let next = if let Some(end) = end {
             need_val = true;
@@ -810,6 +846,9 @@ impl Compiler {
         } else {
             next
         };
+        let next = self
+            .emitter
+            .emit_normal_op(ByteCode::EnterNonPathTracking, next);
         // Same as the above.... although need_val = true.
         let next = if need_val {
             let next = self.emitter.emit_normal_op(ByteCode::Swap, next);
@@ -1348,22 +1387,29 @@ impl Compiler {
                 ) -> Result<Address> {
                     let slot = compiler.allocate_variable();
                     let tmp_slot = compiler.allocate_variable();
+                    let del_slot = compiler.allocate_variable();
                     let label = compiler.current_scope_mut().allocate_label();
 
-                    let after = compiler.emitter.emit_normal_op(ByteCode::Load(slot), next);
+                    let after = compiler.emitter.emit_normal_op(
+                        ByteCode::Intrinsic1(NamedFn1 {
+                            name: "delpaths",
+                            func: intrinsic::del_paths,
+                        }),
+                        next,
+                    );
+                    let after = compiler
+                        .emitter
+                        .emit_normal_op(ByteCode::Load(del_slot), after);
+                    let after = compiler.emitter.emit_normal_op(ByteCode::Load(slot), after);
                     let after = compiler.emitter.emit_normal_op(ByteCode::Pop, after);
 
                     let on_empty = compiler.emitter.emit_terminal_op(ByteCode::Break(label));
                     let on_empty = compiler
                         .emitter
                         .emit_normal_op(ByteCode::Store(slot), on_empty);
-                    let on_empty = compiler.emitter.emit_normal_op(
-                        ByteCode::Intrinsic1(NamedFn1 {
-                            name: "delpath",
-                            func: intrinsic::del_path,
-                        }),
-                        on_empty,
-                    );
+                    let on_empty = compiler
+                        .emitter
+                        .emit_normal_op(ByteCode::Append(del_slot), on_empty);
                     let on_empty = compiler.emitter.emit_normal_op(ByteCode::Pop, on_empty);
 
                     // for each path(lhs), call set_path(., path, . | getpath(path) | rhs) for the first value produced
@@ -1401,6 +1447,12 @@ impl Compiler {
                     let next = compiler.emitter.emit_normal_op(ByteCode::Store(slot), next);
                     let next = compiler.emitter.emit_normal_op(ByteCode::Dup, next);
                     let next = compiler.emitter.emit_fork(after, next);
+                    let next = compiler
+                        .emitter
+                        .emit_normal_op(ByteCode::Store(del_slot), next);
+                    let next = compiler
+                        .emitter
+                        .emit_normal_op(ByteCode::Push(Array::new().into()), next);
                     Ok(next)
                 }
 
@@ -1531,6 +1583,21 @@ impl Compiler {
         Ok(ret)
     }
 
+    fn compile_without_path_tracking<T: Compile>(
+        &mut self,
+        body: &T,
+        next: Address,
+    ) -> Result<Address> {
+        let next = self
+            .emitter
+            .emit_normal_op(ByteCode::ExitNonPathTracking, next);
+        let next = body.compile(self, next)?;
+        let next = self
+            .emitter
+            .emit_normal_op(ByteCode::EnterNonPathTracking, next);
+        Ok(next)
+    }
+
     fn compile_prelude(&mut self, ast: &ast::Program) -> Result<()> {
         assert!(ast.module_header.is_none());
         assert!(ast.imports.is_empty());
