@@ -9,7 +9,7 @@ use crate::{
     Array, Value,
 };
 use itertools::Itertools;
-use num::ToPrimitive;
+use num::{Float, ToPrimitive};
 use phf::phf_map;
 use std::rc::Rc;
 
@@ -18,7 +18,7 @@ pub(crate) use self::{
     comparator::comparator,
     index::{index, slice},
     path::{del_paths, get_path, set_path},
-    string::{stringifier, text},
+    string::{explode, implode, stringifier, text},
     unary::unary,
 };
 
@@ -40,6 +40,8 @@ static INTRINSICS0: phf::Map<&'static str, NamedFn0> = phf_map! {
     "reverse" => NamedFn0 { name: "reverse", func: reverse },
     "tostring" => NamedFn0 { name: "tostring", func: text },
     "tonumber" => NamedFn0 { name: "to_number", func: string::to_number },
+    "explode" => NamedFn0 { name: "explode", func: explode },
+    "implode" => NamedFn0 { name: "implode", func: implode },
 
     "nan" => NamedFn0 { name: "nan", func: math::nan },
     "infinite" => NamedFn0 { name: "infinite", func: math::infinite },
@@ -121,7 +123,7 @@ fn length(context: Value) -> Result<Value> {
     Ok(Value::number(match context {
         Value::Null => 0,
         Value::Boolean(_) => return Err(QueryExecutionError::InvalidArgType("length", context)),
-        Value::Number(_) => return Ok(context),
+        Value::Number(n) => return Ok(n.abs().into()),
         Value::String(s) => s.chars().count(),
         Value::Array(a) => a.len(),
         Value::Object(o) => o.len(),
@@ -247,13 +249,15 @@ fn indices(context: Value, s: Value) -> Result<Value> {
                 .collect(),
         )
         .into(),
-        (Value::Array(lhs), Value::Array(rhs)) => Array::from_vec(
+        (Value::Array(lhs), Value::Array(rhs)) => Array::from_vec(if rhs.is_empty() {
+            vec![]
+        } else {
             lhs.windows(rhs.len())
                 .enumerate()
                 .filter(|(_, lhs)| lhs.iter().eq(rhs.iter())) // TODO: NaN
                 .map(|(pos, _)| Value::Number(pos.into()))
-                .collect(),
-        )
+                .collect()
+        })
         .into(),
         (Value::Array(lhs), rhs) => Array::from_vec(
             lhs.iter()
@@ -279,4 +283,4 @@ fn ends_with(context: Value, s: Value) -> Result<Value> {
         (Value::String(lhs), Value::String(rhs)) => Ok(lhs.ends_with(rhs.as_ref()).into()),
         (context, _) => Err(QueryExecutionError::InvalidArgType("endswith", context)),
     }
-}
\ No newline at end of file
+}
