@@ -1080,4 +1080,88 @@ test!(
     "#
 );
 
+test!(
+    combinations1,
+    r#"
+    combinations
+    "#,
+    r#"
+    [[1,2], [3, 4]]
+    "#,
+    r#"
+    [1, 3]
+    [1, 4]
+    [2, 3]
+    [2, 4]
+    "#
+);
+
+test!(
+    combinations2,
+    r#"
+    combinations(2)
+    "#,
+    r#"
+    [0,1]
+    "#,
+    r#"
+    [0, 0]
+    [0, 1]
+    [1, 0]
+    [1, 1]
+    "#
+);
+
+test!(
+    ltrimstr1,
+    r#"
+    [.[]|ltrimstr("foo")]
+    "#,
+    r#"
+    ["fo", "foo", "barfoo", "foobar", "afoo"]
+    "#,
+    r#"
+    ["fo","","barfoo","bar","afoo"]
+    "#
+);
+
+test!(
+    rtrimstr1,
+    r#"
+    [.[]|rtrimstr("foo")]
+    "#,
+    r#"
+    ["fo", "foo", "barfoo", "foobar", "foob"]
+    "#,
+    r#"
+    ["fo","","bar","foobar","foob"]
+    "#
+);
+
+test!(
+    explode1,
+    r#"
+    explode
+    "#,
+    r#"
+    "foobar"
+    "#,
+    r#"
+    [102,111,111,98,97,114]
+    "#
+);
+
+test!(
+    implode1,
+    r#"
+    implode
+    "#,
+    r#"
+    [65, 66, 67]
+    "#,
+    r#"
+    "ABC"
+    "#
+);
+
 // TODO: Add more
